/* The name of this package */
#undef PACKAGE

/* The version number of the release that is being developed.  */
#undef VERSION

/* Define to `int' if <sys/types.h> doesn't define.  */
#undef ssize_t

/* definition for Default Char Set */
#undef FALLBACK_ENCODING
